@@ -5,7 +5,7 @@
 #' creates initial values for the minimization of the negative log-likelihood
 #' returned by
 #' \ifelse{html}{\code{\link[aldvmm]{aldvmm.ll}}}{\code{aldvmm.ll()}} using
-#' \ifelse{html}{\code{\link[optimr]{optimr}}}{\code{optimr::optimr()}}.
+#' \ifelse{html}{\code{\link[optimx]{optimr}}}{\code{optimx::optimr()}}.
 #'
 #' @inheritParams aldvmm
 #' @inheritParams aldvmm.ll
@@ -29,7 +29,10 @@
 #'   are replaced with the user-specified values, and the method
 #'   \code{"L-BFGS-B"} is used for box-constrained optimization instead of the
 #'   user defined \code{'optim.method'}.  It is possible to only set either
-#'   maximum or minimum limits.
+#'   maximum or minimum limits.  When initial values supplied to 
+#'   \code{'init.est'} or from default methods lie outside the limits, the 
+#'   in-feasible values will be set to the limits using the function 
+#'   \ifelse{html}{\code{\link[optimx]{bmchk}}}{\code{optimx::bmchk()}}.
 #'
 #' @return
 #' \ifelse{html}{\code{\link[aldvmm]{aldvmm.init}}}{\code{aldvmm.init()}}
@@ -140,7 +143,7 @@ aldvmm.init <- function(X,
                            dimnames = list(NULL, "(Intercept)")) )
         names(X0) <- lcoef[1]
       }
-
+      
       # Initial values of constant-only model
       tmp <- list()
       for (i in names(zero)) {
@@ -161,7 +164,7 @@ aldvmm.init <- function(X,
       }
       
       # Fit model
-      fit <- optimr::optimr(method       = optim.method,
+      fit <- optimx::optimr(method       = optim.method,
                             fn           = aldvmm.ll,
                             par          = tmp,
                             X            = X0,
@@ -270,6 +273,17 @@ aldvmm.init <- function(X,
   }
   names(init[["hi"]]) <- names(init[["est"]])
   
+  # Set initial values outside constraint to bounds
+  #------------------------------------------------
+  
+  bc <- optimx::bmchk(init[["est"]], 
+                      lower = init[["lo"]], 
+                      upper = init[["hi"]])
+  
+  if(bc[["parchanged"]] == TRUE) {
+    init[["est"]] <- bc[["bvec"]]
+  }
+  
   return(init)
   
 }
